﻿using System.ComponentModel.DataAnnotations;

namespace BPA.SaaS.Stock.Api.DTO.CRM.Coupon
{
   /// <summary>
   /// 优惠卷基础信息
   /// </summary>
   public class CouponBasetDto
    {
        /// <summary> 
        /// Id 
        /// </summary> 
        public string Id { get; set; }
        /// <summary> 
        /// 优惠券标题 
        /// </summary>
        [Required]
        public string CouponTitle { get; set; }
        /// <summary> 
        /// 优惠券类型(1.满减优惠卷  2.代金优惠卷  3.无门槛优惠卷) 
        /// </summary>
        [Range(1, 3, ErrorMessage = "优惠卷类型错误")]
        public int CouponType { get; set; }
        /// <summary> 
        /// 优惠券值(优惠金额) 
        /// </summary> 
        public decimal CouponValue { get; set; }
        /// <summary> 
        /// 使用条件 
        /// </summary> 
        public decimal Condition { get; set; }
        /// <summary> 
        /// 使用时间的类型 1.时间范围内  2.固定期限 
        /// </summary>
        [Range(1, 2, ErrorMessage = "时间类型错误")]
        public int TimeType { get; set; }
        /// <summary> 
        /// 固定期限值（如领取后10内有效） 
        /// </summary> 
        public int ValidFixedTerm { get; set; }
        /// <summary> 
        /// 开始时间 
        /// </summary> 
        public DateTime ValidStartTime { get; set; }
        /// <summary> 
        /// 结束时间 
        /// </summary> 
        public DateTime ValidEndTime { get; set; }
        /// <summary> 
        /// 状态（1:生效、2：失效 3：作废） 
        /// </summary>
        [Range(1, 3, ErrorMessage = "状态错误")]
        public int ValidStatus { get; set; }
        /// <summary> 
        /// 每人可领取数量 
        /// </summary> 
        [Range(0,999999)]
        public int GetLimit { get; set; }
        /// <summary> 
        /// 备注 
        /// </summary> 
        public string Remarks { get; set; }
        /// <summary> 
        /// 是否删除 
        /// </summary> 
        public int IsDeleted { get; set; }
        /// <summary> 
        /// 创建时间 
        /// </summary> 
        public DateTime CreateAt { get; set; }
        /// <summary> 
        /// 创建人 
        /// </summary> 
        public string CreateBy { get; set; }
        /// <summary> 
        /// 修改时间 
        /// </summary> 
        public DateTime UpdateAt { get; set; }
        /// <summary> 
        /// 修改人 
        /// </summary> 
        public string UpdateBy { get; set; }
        /// <summary> 
        /// 删除时间 
        /// </summary> 
        public DateTime DeleteAt { get; set; }
        /// <summary> 
        /// 删除人 
        /// </summary> 
        public string DeleteBy { get; set; }
        /// <summary> 
        /// 创建人类型(0.供应商 1.平台  ) 
        /// </summary> 
        public int CreateType { get; set; }

        public  bool IsAllowUpdate { get; set; }
        public int SendNum { get; set; }
        public int GetNum { get; set; }

    }
}
