﻿using BPA.Component.ApolloClient;
using BPA.Component.DbClient;
using BPA.Component.MongoClient;
using BPA.Component.RabbitMQClient.Connection;
using Com.Ctrip.Framework.Apollo;
using Microsoft.Extensions.Configuration;
using SqlSugar;

namespace BPA.SaaS.Stock.Api.Model;

/// <summary>
/// StockWebApiConfig
/// </summary>
// ReSharper disable once ClassNeverInstantiated.Global
public class StockWebApiConfig : ApolloBPAConfig<StockWebApiConfig>
{
    /// <summary>
    /// Mysql数据库配置
    /// </summary>
    [AutoWrite]
    public new DbConfig MySqlDb { get; set; }

    /// <summary>
    /// SqlServer数据库配置
    /// </summary>
    [AutoWrite]
    public new DbConfig SqlServerDb { get; set; }

    /// <summary>
    /// MongoDb配置
    /// </summary>
    [AutoWrite]
    public List<MongoConfig> MongoConfig { get; set; }

    /// <summary>
    /// 是否打印SQL
    /// </summary>
    [AutoWrite]
    public bool IsLogSql { get; set; } = true;

    /// <summary>
    /// 数据库类型
    /// </summary>
    [AutoWrite]
    public DbType DbType { get; set; } = DbType.SqlServer;

    /// <summary>
    /// RabbitMQ配置
    /// </summary>
    [AutoWrite]
    public new RabbitMqConnectionConfig RabbitMqConfig { get; set; }

#pragma warning disable CS0618
    public StockWebApiConfig(ApolloConfigurationManager apolloConfigurationManager, IConfiguration configuration) : base(
#pragma warning restore CS0618
        apolloConfigurationManager, configuration)
    {
    }
}